==> soceda-platform-installer-with-mock-v0.4-sources.jar: src/main.js <==
//SOCEDA integration
//----------
//-- Main --
//----------
importPackage(java.lang);
importPackage(java.util);
importPackage(java.io);

//Load files
load("src/util.js");
load("src/dsb.js"); // EasyESB
load("src/gov.js"); // EasierGOV
load("src/bsm.js"); // EasierBSM
load("src/sc.js"); // SeaCloud
load("src/ec.js"); // EventCloud
load("src/cep.js"); // CEP (ie DiCEPE)
load("src/ela.js"); // ELA
load("src/eval.js"); // EVAL
load("src/sccli.js"); // SeaCloud CLI
load("src/tomcat.js"); // Tomcat

{
	println("--------------------------------------------");
	println("--   Welcome to SOCEDA Framework With Mock " + findPropertyInInstaller("installer.version") + "  --");
	println("--         http://www.soceda.org          --");
	println("--------------------------------------------");

	// Check current dir
	checkCurrentLocation();

	// Install SeaCloud CLI
	installSCCLI();

	// Start all components of Soceda Framework
	var waiterThread = startAllComponents();

	println("Please wait until all components are started ...");

	readStdin("Once ready press 'Enter' to connect all components of the SOCEDA Framework ...");
	connectAllComponents();

	println(""); 
	println("Congratulation!!!"); 
	println("The SOCEDA Framework is ready...");

	// The main will terminate when the waiter thread terminates
	waiterThread.join();
}


function startAllComponents() {
	// Start CEP Mocked
	var cepProcess = runCEP();
	println("CEP started ...");

	// Start EventCloud Mocked	
	var ecProcess = runEC();
	println("EventCloud started ...");		

	// Start EasierGOV
	var govProcess = runGOV();
	println("EasierGOV started ...");

	// Start EasierESB
	var dsbProcess = runDSB();
	println("EasyESB started ...");	

	// Start EasierBSM
	var bsmProcess = runBSM();
	println("EasierBSM started ...");	
	
	// Start Eval
	var evalProcess = runEval();
	println("Eval Logger started ...");	
	
	// Start ELA ALERT Service
	var elaProcess = runELA();
	println("ELA Alert Service started ...");	

	// Start SeaCloud
	var scProcess = runSC();
	println("SeaCloud started ...");

	// Start Tomcat
	var tomcatProcess = runTomcat();
	println("Tomcat created ...");	

	// Add hook that terminates all if the current process is killed 
	var cleaner = java.lang.Thread(function () {

		println("Terminating EasyESB ...");
		dsbProcess.destroy();
		println("Terminating EasierGOV ...");
		govProcess.destroy();
		println("Terminating EasierBSM ...");
		bsmProcess.destroy();
		println("Terminating Eval Logger...");
		evalProcess.destroy();
		println("Terminating ELA Alert Service ...");
		elaProcess.destroy();
		println("Terminating EventCloud ...");
		ecProcess.destroy();
		println("Terminating Tomcat ...");
		tomcatProcess.destroy();
		println("Terminating SeaCloud ...");
		scProcess.destroy();
		println("Terminating CEP ...");
		cepProcess.destroy();
	});
	java.lang.Runtime.getRuntime().addShutdownHook(cleaner);

	// Add async waiter thread 
	var waiter = java.lang.Thread(function () {
		// Wait for 
		dsbProcess.waitFor();
		govProcess.waitFor();
		bsmProcess.waitFor();
		evalProcess.waitFor();
		elaProcess.waitFor();
		ecProcess.waitFor();	
		tomcatProcess.waitFor();
		scProcess.waitFor();
		cepProcess.waitFor();
	});
	waiter.start();
	return waiter;
}

function connectAllComponents() {
	var scriptFile = new File(scriptsDir, "ConnectAllComponentsScript.xml");
	println("SeaCloud CLI runs " + scriptFile + " ...");
	var sccliProcess = 	runDescriptor(scriptFile);		
	sccliProcess.waitFor();	
}

==> soceda-platform-installer-with-mock-v0.5-sources.jar: src/main.js <==
//SOCEDA integration
//----------
//-- Main --
//----------
importPackage(java.lang);
importPackage(java.util);
importPackage(java.io);

//Load files
load("src/util.js");
load("src/dsb.js"); // EasyESB
load("src/gov.js"); // EasierGOV
load("src/bsm.js"); // EasierBSM
load("src/sc.js"); // SeaCloud
load("src/ec.js"); // EventCloud
load("src/sf.js"); // SocialFilter
load("src/cep.js"); // CEP (ie DiCEPE)
load("src/ela.js"); // ELA
load("src/eval.js"); // EVAL
load("src/sccli.js"); // SeaCloud CLI
load("src/tomcat.js"); // Tomcat

{
	println("--------------------------------------------");
	println("--   Welcome to SOCEDA Framework With Mock " + findPropertyInInstaller("installer.version") + "  --");
	println("--         http://www.soceda.org          --");
	println("--------------------------------------------");

	// Check current dir
	checkCurrentLocation();

	// Install SeaCloud CLI
	installSCCLI();

	// Start all components of Soceda Framework
	var waiterThread = startAllComponents();

	println("Please wait until all components are started ...");

	readStdin("Once ready press 'Enter' to connect all components of the SOCEDA Framework ...");
	connectAllComponents();

	println(""); 
	println("Congratulation!!!"); 
	println("The SOCEDA Framework is ready...");

	// The main will terminate when the waiter thread terminates
	waiterThread.join();
}


function startAllComponents() {
	// Start CEP Mocked
	var cepProcess = runCEP();
	println("CEP started ...");
	
	// Start Social Filter Mocked	
	var sfProcess = runSF();
	println("SocialFilter started ...");		

	// Start EventCloud Mocked	
	var ecProcess = runEC();
	println("EventCloud started ...");		

	// Start EasierGOV
	var govProcess = runGOV();
	println("EasierGOV started ...");

	// Start EasierESB
	var dsbProcess = runDSB();
	println("EasyESB started ...");	

	// Start EasierBSM
	var bsmProcess = runBSM();
	println("EasierBSM started ...");	
	
	// Start Eval
	var evalProcess = runEval();
	println("Eval Logger started ...");	
	
	// Start ELA ALERT Service
	var elaProcess = runELA();
	println("ELA Alert Service started ...");	

	// Start SeaCloud
	var scProcess = runSC();
	println("SeaCloud started ...");

	// Start Tomcat
	var tomcatProcess = runTomcat();
	println("Tomcat created ...");	

	// Add hook that terminates all if the current process is killed 
	var cleaner = java.lang.Thread(function () {

		println("Terminating EasyESB ...");
		dsbProcess.destroy();
		println("Terminating EasierGOV ...");
		govProcess.destroy();
		println("Terminating EasierBSM ...");
		bsmProcess.destroy();
		println("Terminating Eval Logger...");
		evalProcess.destroy();
		println("Terminating ELA Alert Service ...");
		elaProcess.destroy();
		println("Terminating EventCloud ...");
		ecProcess.destroy();
		println("Terminating Tomcat ...");
		tomcatProcess.destroy();
		println("Terminating SeaCloud ...");
		scProcess.destroy();
		println("Terminating CEP ...");
		cepProcess.destroy();
		println("Terminating EC ...");
		ecProcess.destroy();
		println("Terminating SF ...");
		sfProcess.destroy();
	});
	java.lang.Runtime.getRuntime().addShutdownHook(cleaner);

	// Add async waiter thread 
	var waiter = java.lang.Thread(function () {
		// Wait for 
		dsbProcess.waitFor();
		govProcess.waitFor();
		bsmProcess.waitFor();
		evalProcess.waitFor();
		elaProcess.waitFor();
		ecProcess.waitFor();	
		sfProcess.waitFor();	
		tomcatProcess.waitFor();
		scProcess.waitFor();
		cepProcess.waitFor();
	});
	waiter.start();
	return waiter;
}

function connectAllComponents() {
	var scriptFile = new File(scriptsDir, "ConnectAllComponentsScript.xml");
	println("SeaCloud CLI runs " + scriptFile + " ...");
	var sccliProcess = 	runDescriptor(scriptFile);		
	sccliProcess.waitFor();	
}
